<template>
  <!-- {direction: 'DESC', property: 'bpa.CONFERENCE_PLACE_'}, -->
  <at-table
    @load="loadData"
    :data="data"
    :page-result="pageResult"
    ref="AtTable"
    :dialogTitle="dialogTitle"
    :dialogVisible="dialogVisible"
    :default-sorter="[{direction: 'DESC', property: 'conferenceDate'}]"
    @select-all="handleSelect"
    @select="handleSelect"
    @handleDialogCancel="handleDialogCancel"
    @handleDialogClose="handleDialogClose"
    @handleDialogSubmit="handleDialogSubmit"
    @row-dblclick="handleRowDBClick"
  >
    <template v-slot:searchInput>
      <el-form
        ref="searchForm"
        :model="searchForm"
        label-width="80px"
        class="search-top"
        @submit.native.prevent
      >
        <project-info-selector
          v-if="isShow"
          v-model="searchForm.projectId"
          style="width: 100%"
        ></project-info-selector>
        <el-date-picker
          v-model="searchForm.conferenceDate"
          type="date"
          placeholder="选择会议时间"
          value-format="yyyy-MM-dd"
          format="yyyy-MM-dd"
          style="width: 100%"
          @keyup.enter.native="findinfo"
        >
        </el-date-picker>
        <el-input
          v-model="searchForm.conferenceTheme"
          style="width: 100%"
          placeholder="请输入会议主题"
          clearable
          @keyup.enter.native="findinfo"
        ></el-input>
        <el-button
          size="small"
          @click="findinfo"
          type="primary"
          class="el-icon-search search-btn"
          >查询</el-button
        >
        <el-button
          size="small"
          @click="handleReset"
          type="primary"
          plain
          class="el-icon-refresh"
          >重置</el-button
        >
      </el-form>
    </template>
    <template v-slot:operationBtn>
      <el-button
        size="small"
        type="primary"
        @click="handleAdd"
        icon="el-icon-plus"
        >添加</el-button
      >
      <ht-delete-button
        :url="deleteUrl"
        :requestMethod="'POST'"
        :htTable="$refs.AtTable"
        >删除</ht-delete-button
      >
      <import-file :importData="importData" @load="load"></import-file>
      <el-button
        size="small"
        type="primary"
        @click="handleExport"
        icon="el-icon-download"
        plain
        style="margin-left: 10px"
        >导出</el-button
      >
    </template>
    <template>
      <el-table-column type="selection" width="55" align="center">
      </el-table-column>
      <el-table-column type="index" label="序号" width="55" align="center">
      </el-table-column>
      <el-table-column
        prop="projectInfo.projectName"
        label="项目名称"
        :show-overflow-tooltip="true"
        align="center"
      >
      </el-table-column>
       <el-table-column
        prop="conferenceTheme"
        label="会议主题"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="conferenceDate"
        label="会议时间"
        align="center"
        width="150"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <el-table-column
        prop="conferencePlace"
        label="会议地点"
        align="center"
         width="200"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
      <!-- <el-table-column
        prop="conferenceUnit"
        label="参加单位"
        align="center"
        :show-overflow-tooltip="true"
      >
      </el-table-column> -->
     
      <el-table-column
        prop="remarks"
        label="备注"
        align="center"
        width="100"
        :show-overflow-tooltip="true"
      >
      </el-table-column>
    </template>
    <template v-slot:dialogContent>
      <el-form
        ref="form"
        v-form
        data-vv-scope="form"
        :model="form"
        :rules="rules"
        label-width="130px"
        v-if="dialogVisible"
        v-loading.fullscreen="loading"
      >
        <el-row>
          <el-col :span="12">
            <el-form-item label="项目名称" prop="projectInfo.projectName">
              <el-input
                v-model="form.projectInfo.projectName"
                placeholder="请选择项目名称"
                @focus="handleFocusProject"
                :disabled="!isShow"
                clearable
              >
                <el-button
                  type="primary"
                  @click="openProject"
                  slot="append"
                  icon="el-icon-search"
                ></el-button>
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="经办人" prop="handler">
              <el-input
                v-model="form.handler"
                placeholder="请输入经办人"
                clearable
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="12">
            <el-form-item label="会议时间" prop="conferenceDate">
              <el-date-picker
                v-model="form.conferenceDate"
                type="date"
                placeholder="选择会议时间"
                value-format="yyyy-MM-dd"
                format="yyyy-MM-dd"
                style="width: 100%"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="会议地点" prop="conferencePlace">
              <el-input
                v-model="form.conferencePlace"
                placeholder="请输入会议地点"
                clearable
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row> </el-row>
        <el-form-item label="会议主题" prop="conferenceTheme">
          <el-input
            v-model="form.conferenceTheme"
            placeholder="请输入会议主题"
            clearable
          ></el-input>
        </el-form-item>

        <el-form-item label="参加单位" prop="conferenceUnit">
          <el-input
            v-model="form.conferenceUnit"
            placeholder="请输入参加单位"
            type="textarea"
            rows="3"
            clearable
          ></el-input>
        </el-form-item>
        <el-form-item label="备注" prop="remarks">
          <el-input
            v-model="form.remarks"
            placeholder="请输入备注"
            type="textarea"
            clearable
          ></el-input>
        </el-form-item>
        <file-table
          @handleFile="handleFile"
          :file="form.accessoryInfo"
          :info="'上传技术资料会议纪要等文件'"
        />
        <project-info-dialog
          ref="project"
          :single="true"
          @select="handleSelectProject"
        ></project-info-dialog>
      </el-form>
    </template>
  </at-table>
</template>

<script>
import req from '@/request.js'
import ProjectInfoDialog from '@/components/dialog/ProjectInfoDialog.vue'
const eipUserSelector = () =>
  import('@/components/selector/EipUserSelector.vue')
export default {
  name: 'TechnicalInformation',
  components: {
    ProjectInfoDialog,
    // eipUserSelector
  },
  props: {
    pid: {
      type: String,
      default: '',
    },
    isShow: {
      type: Boolean,
      default: true,
    },
  },
  data() {
    return {
      importData: {
        title: '技术资料',
        templateName: '技术资料模板.xls',
        downloadUrl: '/../fvue/static/excel/ExportPreAcceptance.xlsx',
        importUrl:
          window.context.cqxy +
          '/biz/processManagement/technicalInformation/v1/importExcelData',
        showProject: true,
        projectId: '',
        // params: {
        //   preAcceptancePersonId: '',
        //   handler: '',
        // },
      },
      projectObj: [],
      searchInfo: {},
      loading: false,
      searchForm: {
        projectId: '',
        planAcceptanceDate: '',
        actualAcceptanceDate: '',
        preAcceptancePersonId: '',
      }, //顶部搜索参数
      data: [], //表格数据
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0,
      },
      form: {},
      dialogVisible: false,
      dialogTitle: '添加',
      indexArr: [],
      rules: {
        'projectInfo.projectName': {
          required: true,
          message: '请选择项目名称',
          trigger: 'blur',
        },
        'projectInfo.projectCode': {
          required: true,
          message: '请选择项目代码',
          trigger: 'blur',
        },
      },
    }
  },
  computed: {
    deleteUrl: function () {
      return (
        window.context.cqxy +
        '/biz/processManagement/technicalInformation/v1/delete'
      )
    },
  },
  mounted() {
    this.initProjectAll()
  },
  methods: {
    handleReset() {
      this.searchForm.projectId = ''
      this.searchForm.conferenceDate = ''
      this.searchForm.conferenceTheme = ''
      this.$refs['searchForm'].resetFields()
      this.pageResult = {
        page: 1,
        pageSize: 20,
        total: 0,
      }
      this.$refs['searchForm'].resetFields()
      this.$nextTick(() => {
        this.$refs.AtTable.load()
      })
    },
    //导入后重新加载数据
    load() {
      this.$refs.AtTable.load()
    },
    //导出
    handleExport() {
      let query = []
      let search = {
        'pm.ID_': this.searchForm.projectId,
        conference_date_: this.searchForm.conferenceDate,
        conference_theme_: this.searchForm.conferenceTheme,
      }
      if (!this.isShow) {
        search['pm.ID_'] = this.pid
      }
      for (let i in search) {
        if (search[i]) {
          query.push({
            group: 'advance',
            operation: 'LIKE',
            property: i,
            relation: 'AND',
            value: search[i],
          })
        }
      }
      let param = {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true,
        },

        querys: query,
        sorter: [],
      }
      req
        .downloadPostCopy(
          '${cqxy}/biz/processManagement/technicalInformation/v1/exportDataToExcel',
          param
        )
        .then((res) => {
          if (res.status === 200) {
            this.$message.success('导出成功')
          } else {
            this.$message.error('导出失败')
          }
        })
    },
    handleFile(file) {
      this.form.accessoryInfo = file
    },
    handleAdd() {
      this.dialogTitle = '添加'
      this.form = {
        projectInfo: {
          projectName: '',
          projectCode: '',
        },
        handler: '',
        accessoryInfo: [],
      }
      this.dialogVisible = true
      //获取当前项目
      if (this.isShow) {
        let selectedProject = this.projectObj.find((item) => {
          if (item.currentProject && item.currentProject == 1) {
            return item.currentProject == 1
          }
        })
        this.form.projectInfo.projectName = selectedProject.projectName
        this.form.projectInfo.projectCode = selectedProject.projectCode
        this.form.projectId = selectedProject.id
        this.form.handler = selectedProject.projectManager
      } else {
        //根据项目id查询
        this.form.projectInfo.projectName = this.projectObj[0].projectName
        this.form.projectInfo.projectCode = this.projectObj[0].projectCode
        this.form.projectId = this.projectObj[0].id
        this.form.handler = this.projectObj[0].projectManager
      }
    },
    handleRowDBClick(data) {
      this.dialogTitle = '修改'
      this.form = data
      this.dialogVisible = true
    },
    handleFocusProject() {
      this.$refs.project.open()
    },
    openProject() {
      this.$refs.project.open()
    },
    handleSelectProject(data) {
      this.form.projectId = data.id
      this.form.projectInfo.projectCode = data.projectCode
      this.form.projectInfo.projectName = data.projectName
      this.form.handler = data.projectManager
      this.$refs.form.clearValidate()
    },
    handleSelect(selection) {},
    handleDialogCancel() {
      this.dialogVisible = false
    },
    handleDialogClose() {
      this.dialogVisible = false
    },
    initProjectAll() {
      //初始获取所有项目数据
      if (this.isShow) {
        this.$http.post('${cqxy}/biz/projectManagement/pm/v1/All').then(
          (res) => {
            this.projectObj = res.data.value
          },
          (error) => {
            reject(error)
          }
        )
      } else {
        let params = {
          pageBean: {
            page: 1,
            pageSize: 500,
            total: 0,
          },
          querys: [
            {
              group: 'main',
              operation: 'EQUAL',
              property: 'id',
              relation: 'AND',
              value: this.pid,
            },
          ],
        }
        this.$http
          .post('${cqxy}/biz/projectManagement/pm/v1/page', params)
          .then((res) => {
            if (res.data.state) {
              let resp = res.data.value
              this.projectObj = resp.rows
            }
          })
      }
    },
    //提交保存
    handleDialogSubmit() {
      this.$refs.form.validate((valid) => {
        if (valid) {
          if (this.form.accessoryInfo && this.form.accessoryInfo.length > 0) {
            this.form.accessoryInfo.forEach((item) => {
              if (item.id) {
                delete item.id
              }
            })
          }
          this.loading = true
          this.$http
            .post(
              '${cqxy}/biz/processManagement/technicalInformation/v1/save',
              this.form
            )
            .then((res) => {
              if (res.data.state) {
                this.$refs.form.resetFields()
                this.$message.success(res.data.message)
                this.dialogVisible = false
                this.$refs.AtTable.load()
              } else {
                this.$message.error(res.data.message)
              }
              this.loading = false
            })
        }
        // else if (this.form.accessoryInfo.length === 0) {
        //   this.$message.error('请至少上传一个附件')
        // }
        else {
          this.$message({
            message: '*号必填项,不能为空!',
            type: 'warning',
          })
          return false
        }
      })
    },
    loadData(param, cb) {
      let query = []
      let search = {
        'pm.ID_': this.searchForm.projectId,
        conference_date_: this.searchForm.conferenceDate,
        conference_theme_: this.searchForm.conferenceTheme,
      }
      if (!this.isShow) {
        search['pm.ID_'] = this.pid
        this.importData.projectId = this.pid
      }
      for (let i in search) {
        if (search[i]) {
          query.push({
            group: 'advance',
            operation: 'LIKE',
            property: i,
            relation: 'AND',
            value: search[i],
          })
        }
      }

      if (param.querys && param.querys.length) {
        param.querys.push(...query)
      } else {
        param.querys = query
      }
      this.$http
        .post(
          '${cqxy}/biz/processManagement/technicalInformation/v1/page',
          param
        )
        .then(
          (resp) => {
            let response = resp.data.value
            this.data = response.rows
            this.pageResult = {
              page: response.page,
              pageSize: response.pageSize,
              total: response.total,
            }
          },
          (error) => {
            reject(error)
          }
        )
        .finally(() => {
          if (cb) {
            cb()
          }
        })
    },
    findinfo() {
      this.$refs.AtTable.load()
    },
  },
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/common.scss';
/deep/ .el-range-editor--small .el-range-separator {
  display: contents;
}
</style>
